# pydbm

**pydbm is an ORM for dbm.**

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/hakancelikdev/pydbm/main.svg)](https://results.pre-commit.ci/latest/github/hakancelikdev/pydbm/main)
[![test](https://github.com/hakancelikdev/pydbm/actions/workflows/tests.yml/badge.svg)](https://github.com/hakancelikdev/pydbm/actions/workflows/tests.yml)
[![build-docs](https://github.com/hakancelikdev/pydbm/actions/workflows/docs.yml/badge.svg)](https://github.com/hakancelikdev/pydbm/actions/workflows/docs.yml)
[![publish-package-on-pypi](https://github.com/hakancelikdev/pydbm/actions/workflows/pypi.yml/badge.svg)](https://github.com/hakancelikdev/pydbm/actions/workflows/pypi.yml)

[![Pypi](https://img.shields.io/pypi/v/pythonic-dbm)](https://pypi.org/project/pythonic-dbm/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pythonic-dbm)
[![Downloads](https://static.pepy.tech/personalized-badge/pythonic-dbm?period=total&units=international_system&left_color=grey&right_color=red&left_text=downloads)](https://pepy.tech/project/pythonic-dbm)
[![License](https://img.shields.io/github/license/hakancelikdev/pydbm.svg)](https://github.com/hakancelikdev/pydbm/blob/main/LICENSE)

[![Forks](https://img.shields.io/github/forks/hakancelikdev/pydbm)](https://github.com/hakancelikdev/pydbm/fork)
[![Issues](https://img.shields.io/github/issues/hakancelikdev/pydbm)](https://github.com/hakancelikdev/pydbm/issues)
[![Stars](https://img.shields.io/github/stars/hakancelikdev/pydbm)](https://github.com/hakancelikdev/pydbm/stargazers)

[![Codecov](https://codecov.io/gh/hakancelikdev/pydbm/branch/main/graph/badge.svg)](https://codecov.io/gh/hakancelikdev/pydbm)
[![Contributors](https://img.shields.io/github/contributors/hakancelikdev/pydbm)](https://github.com/hakancelikdev/pydbm/graphs/contributors)
[![Last Commit](https://img.shields.io/github/last-commit/hakancelikdev/pydbm.svg)](https://github.com/hakancelikdev/pydbm/commits/main)

For more information see: https://pydbm.hakancelik.dev/
